==> md-highlights-0.2.0.tgz: package/index.js <==

var through = require('through2'),
	cheerio = require('cheerio'),
	Highlights = require('highlights'),
	path = require('path');

var highlighter = new Highlights();

module.exports = function(fileOpt, opt) {

	return through.obj(function (file, enc, cb) {

		if (file.isNull()) {
			cb(null, file);
			return;
		}

		if (file.isStream()) {
			//cb(new gutil.PluginError('gulp-markdown', 'Streaming not supported'));
			return;
		}

    	$ = cheerio.load(file.contents.toString());

    	//add extra outer div aroud tables for mobile view
    	$('table').each ( function( index, element ) {

			var table = $('<div>').append($(element).clone()).html();

			$( element ).replaceWith( '<div class="outer-table">' + table + '</div>' );
    	});
    	 
    	//Generate code highlighted blocks
		$('pre code').each ( function( index, element ) {

			//Vars
			var scopeName = null,
				languages = { 
					js: 'source.js',
					py: 'source.python',
					yaml: 'source.yaml',
					php: 'text.html.php'
				}

			//Highlight in the right language
			if( $(element).attr('class') ) {

				for( language in languages) {

					if( 'lang-'+language == $(element).attr('class') ) {

						scopeName = languages[language];
					}
				}
			}

			//Load external PHP grammer
	 		highlighter.requireGrammarsSync({

				modulePath: path.resolve(__dirname,'language-php')
			});

	 		//Highlight code snipped
			var highlightedContainter = highlighter.highlightSync({
			
				fileContents: $(element).text(),
				scopeName: scopeName
			});

			//Push back in master file
			$(element).html( highlightedContainter )
		});

		file.contents = new Buffer( $.html().toString() );

		return cb(null, file);
	});
}

==> md-highlights-0.2.1.tgz: package/index.js <==

var through = require('through2'),
	cheerio = require('cheerio'),
	Highlights = require('highlights'),
	path = require('path');

var highlighter = new Highlights();

module.exports = function(fileOpt, opt) {

	return through.obj(function (file, enc, cb) {

		if (file.isNull()) {
			cb(null, file);
			return;
		}

		if (file.isStream()) {
			//cb(new gutil.PluginError('gulp-markdown', 'Streaming not supported'));
			return;
		}

    	$ = cheerio.load(file.contents.toString());

    	//add extra outer div aroud tables for mobile view
    	$('table').each ( function( index, element ) {

			var table = $('<div>').append($(element).clone()).html();
			
			$( element ).replaceWith( [
				'<div class="table-container">',
				'<span class="arrow-left"></span>',
				'<span class="arrow-right"></span>',
				'<div class="outer-table">',
				table,
				'</div>',
				'</div>' 
			].join(''));


	 	});
    	 
    	//Generate code highlighted blocks
		$('pre code').each ( function( index, element ) {

			//Vars
			var scopeName = null,
				languages = { 
					js: 'source.js',
					py: 'source.python',
					yaml: 'source.yaml',
					php: 'text.html.php'
				}

			//Highlight in the right language
			if( $(element).attr('class') ) {

				for( language in languages) {

					if( 'lang-'+language == $(element).attr('class') ) {

						scopeName = languages[language];
					}
				}
			}

			//Load external PHP grammer
	 		highlighter.requireGrammarsSync({

				modulePath: path.resolve(__dirname,'language-php')
			});

	 		//Highlight code snipped
			var highlightedContainter = highlighter.highlightSync({
			
				fileContents: $(element).text(),
				scopeName: scopeName
			});

			//Push back in master file
			$(element).html( highlightedContainter )
		});

		file.contents = new Buffer( $.html().toString() );

		return cb(null, file);
	});
}
